@@ -16,7 +16,11 @@
 # Import APIs into API package:
 from whylabs_client.api.alerts_api import AlertsApi
 from whylabs_client.api.api_key_api import ApiKeyApi
+from whylabs_client.api.dataset_profile_api import DatasetProfileApi
 from whylabs_client.api.events_api import EventsApi
+from whylabs_client.api.feature_weights_api import FeatureWeightsApi
 from whylabs_client.api.log_api import LogApi
+from whylabs_client.api.membership_api import MembershipApi
 from whylabs_client.api.models_api import ModelsApi
+from whylabs_client.api.notification_settings_api import NotificationSettingsApi
 from whylabs_client.api.sessions_api import SessionsApi
